bl_info = {
    "name": "N-Gon Filler",
    "author": "Lell",
    "version": (0, 1, 0),
    "blender": (2, 6, 5),
    "location": "Search for NGon Filler",
    "description": "Sobstitutes selected N-gons with triangles or a grid",
    "warning": "testing",
    "wiki_url": "",
    "tracker_url": "",
    "category": "Mesh"}
    
import bpy, bmesh
from bpy.props import EnumProperty

def ngon_filler_function(mode, single_vertex_mode):
    
    me = bpy.context.active_object.data #dati geometrici della mesh
    bm = bmesh.from_edit_mesh(me) #trasformo in bmesh
    if mode == "0": #se la modalità del tool è la prima
        sel_faces = [] #lista facce selezionate
        for f in bm.faces: #per ogni poligono della bmesh
            if f.select:  #se è selezionato
                sel_faces.append(f)  #lo aggiungo alla lista

        for f in sel_faces:   #per ogni faccia selezionata
            if single_vertex_mode == "0":  #calcolo la coordinata del nuovo centro
                central_vert_co = f.calc_center_median() 
            elif single_vertex_mode == "1":
                central_vert_co = f.calc_center_bounds()
            elif single_vertex_mode == "2":
                central_vert_co = bpy.context.scene.cursor_location - bpy.context.active_object.location
            bm.verts.new(central_vert_co) #creo un nuovo vertice nella coodinata trovata     
            
            for l in f.loops: #per ogni vertice del bordo della faccia
                bm.faces.new([l.vert, l.link_loop_next.vert, bm.verts[-1]]) #creo un triangolo fra il nuovo vertice centrale, il vertice trovato e il vertice successivo
            bm.faces.remove(f) #rimuovo la vecchia faccia
        me = bm  #riassegno la bmesh alla mesh
    elif mode == "1":
        print("see you soon")        
                                  
    
class NGonFiller(bpy.types.Operator):
    bl_idname = "mesh.ngon_filler"
    bl_label = "NGon Filler"
    bl_description = "N-Gon converter with different options"
    bl_options = {'REGISTER', 'UNDO'}
    
    mode = EnumProperty (items=(("0", "Central Vertex", "Create a single central vertex and triangular faces"), ("1", "Grid", "Create a grid in place of the n-gon")), 
                        name = "Filling Mode", description = "N-Gon filling mode")
    single_vertex_mode = EnumProperty (items = (("0", "Median Point", "Create the vertex in the median point of the n-gon"), ("1", "Bounds center", "Creates the vertex in the center of the n-gon bounds")),
                        name = "Single Vertex Creation Mode", description = "Where the unique vertex will be created")  #,("2", "3D Cursor", "Creates the vertex at the 3D cursor location")
    
    def draw(self, context):
        layout = self.layout
        
        row0 = layout.row()
        row0.prop(self, 'mode', expand = True )
        
        if self.mode == "0":
            row1 = layout.row()
            row1.prop(self, 'single_vertex_mode', expand = True)
                    
    def execute(self, context):
        
        ngon_filler_function(self.mode, self.single_vertex_mode)
        return{'FINISHED'}
    
    @classmethod
    def poll(self, context):
        if context.mode == 'EDIT_MESH':
            return True
         
        return False
    
def register():
    bpy.utils.register_class(NGonFiller)
    
if __name__ == "__main__":
    register()


    